@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2003-2020)
+#   Copyright (C) Dr. Heinz-Josef Claes (2003-2009)
 #                 hjclaes@web.de
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -19,6 +19,9 @@
 #
 
 
+my $VERSION = '$Id: storeBackupDel.pl 356 2009-04-27 08:51:49Z hjc $ ';
+push @VERSION, $VERSION;
+my ($VERSIONpName, $VERSIONsvnID) = $VERSION =~ /Id:\s+(\S+)\s+(\d+)/;
 $main::STOREBACKUPVERSION = undef;
 
 
@@ -98,9 +101,7 @@ require 'dateTools.pl';
 require 'fileDir.pl';
 require 'humanRead.pl';
 
-my $lockFile = ($ENV{'USER'} eq 'root') ?     # default value
-		'/var/lock/storeBackup.lock' :
-		$ENV{'HOME'} . '/storeBackup.lock';
+my $lockFile = '/tmp/storeBackup.lock';   # default value
 my $keepAll = '30d';
 my $keepDuplicate = '7d';
 my $checkSumFile = '.md5CheckSums';
@@ -153,12 +154,7 @@ storeBackupDel.pl - this program deletes backups created by storeBackup
 =item B<--lockFile>, B<-L>
 
     lock file, if exists, new instances will finish if
-    an old is already running, default is $lockFile
-    this type of lock files does not work across multiple servers
-    and is not designed to separate storeBackup.pl and
-    storeBackupUpdateBackup.pl or any other storeBackup
-    process in a separate PID space
-    Default lock file for root is in /var/lock, for others in \$HOME
+    an old is allready running, default is $lockFile
 
 =item B<--doNotDelete>
 
@@ -258,7 +254,7 @@ storeBackupDel.pl - this program deletes backups created by storeBackup
     Alternative deletion scheme. If you use this option, all other
     keep options are ignored. Preserves backups depending
     on their *relative* age. Example:
-    -R '1d 7d 61d 92d'
+    -R '1d 7d 2m 3m'
         will (try to) ensure that there is always
 	- One backup between 1 day and 7 days old
 	- One backup between 5 days and 2 months old
@@ -291,7 +287,7 @@ storeBackupDel.pl - this program deletes backups created by storeBackup
 =item B<--saveLogs>
 
     save log files with date and time instead of deleting the
-    old (with [-noOfOldFiles])
+    old (with [-noOldFiles])
 
 =item B<--compressWith>
 
@@ -302,14 +298,16 @@ storeBackupDel.pl - this program deletes backups created by storeBackup
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2020 by Heinz-Josef Claes (see README).
+Copyright (c) 2003-2008 by Heinz-Josef Claes (see README).
 Published under the GNU General Public License v3 or any later version
 
 =cut
 
-my $Help = &::getPod2Text($0);
+my $Help = join('', grep(!/^\s*$/, `pod2text $0`));
+$Help = "cannot find pod2text, see documentation for details\n"
+    unless $Help;
 
-&printVersion(\@ARGV, '-V', '--version');
+&printVersions(\@ARGV, '-V');
 
 my $startDate = dateTools->new();
 
@@ -398,7 +396,6 @@ my $CheckPar =
 					    '-pattern' => '\A\d+\Z'),
                                 Option->new('-name' => 'keepRelative',
 					    '-cl_option' => '--keepRelative',
-					    '-cl_alias' => '-R',
 					    '-cf_key' => 'keepRelative',
 					    '-quoteEval' => 'yes',
 					    '-param' => 'yes'),
@@ -449,12 +446,7 @@ my $CheckPar =
 					    '-cl_option' => '--today',
 					    '-cf_key' => 'today',
 					    '-hidden' => 'yes',
-					    '-param' => 'yes'),
-# used by storeBackupMount.pl
-				Option->new('-name' => 'writeToNamedPipe',
-					    '-cl_option' => '--writeToNamedPipe',
-					    '-param' => 'yes',
-					    '-hidden' => 'yes')
+					    '-param' => 'yes')
 				]
 		    );
 
@@ -495,11 +487,10 @@ my $maxFilelen = $CheckPar->getOptWithPar('maxFilelen');
 my $noOfOldFiles = $CheckPar->getOptWithPar('noOfOldFiles');
 my $saveLogs = $CheckPar->getOptWithoutPar('saveLogs') ? 'yes' : 'no';
 my $compressWith = $CheckPar->getOptWithPar('compressWith');
-# hidden options
+
 my $printAll = $CheckPar->getOptWithoutPar('printAll');
 $print = 1 if $printAll;
 my $todayOpt = $CheckPar->getOptWithPar('todayOpt');  # format like
-my $writeToNamedPipe = $CheckPar->getOptWithPar('writeToNamedPipe');
                                                       # backup dir name
 
 if ($print)
@@ -508,48 +499,26 @@ if ($print)
     exit 0;
 }
 
-my $prLog1;
-my (@kind) = ('A:BEGIN', 'Z:END','I:INFO', 'W:WARNING', 'E:ERROR',
-	      'S:STATISTIC', 'D:DEBUG', 'V:VERSION');
+my $prLog;
+my (@kind) = ('I:INFO', 'W:WARNING', 'E:ERROR', 'S:STATISTIC',
+	      'D:DEBUG', 'V:VERSION');
 
 if ($logFile)
 {
-    $prLog1 = printLog->new('-kind' => \@kind,
-			    '-file' => $logFile,
-			    '-withTime' => $withTime,
-			    '-maxFilelen' => $maxFilelen,
-			    '-noOfOldFiles' => $noOfOldFiles);
+    $prLog = printLog->new('-kind' => \@kind,
+			   '-file' => $logFile,
+			  '-withTime' => $withTime,
+			  '-maxFilelen' => $maxFilelen,
+			  '-noOfOldFiles' => $noOfOldFiles);
 }
 else
 {
-    $prLog1 = printLog->new('-kind' => \@kind);
+    $prLog = printLog->new('-kind' => \@kind);
 }
 
-my $prLog = printLogMultiple->new('-prLogs' => [$prLog1]);
-
-if ($plusLogStdout)
-{
-    my $p = printLog->new('-kind' => \@kind,,
-			  '-filedescriptor', *STDOUT);
-    $prLog->add('-prLogs' => [$p]);
-}
-if ($writeToNamedPipe)
-{
-    my $np = printLog->new('-kind' => \@kind,
-			   '-file' => $writeToNamedPipe,
-			   '-maxFilelen' => 0);
-    $prLog->add('-prLogs' => [$np]);
-}
-
-(@main::cleanup) = ($prLog, undef);
-$SIG{INT} = \&cleanup;
-$SIG{TERM} = \&cleanup;
-
-$prLog->print('-kind' => 'A',
-	      '-str' =>
-	      ["starting deletion in <$backupDir>, series <$series>"]);
 $prLog->print('-kind' => 'V',
-	      '-str' => ["storeBackupDel.pl, $main::STOREBACKUPVERSION"]);
+	      '-str' => ["$VERSIONpName, $main::STOREBACKUPVERSION, " .
+			 "build $VERSIONsvnID"]);
 
 $prLog->print('-kind' => 'E',
 	      '-str' => ["backupDir directory <$backupDir> does not exist\n$Help"],
@@ -573,7 +542,44 @@ my $allLinks = lateLinks->new('-dirs' => [$targetDir],
 #
 # lock file berprfen
 #
-::checkLockFile($lockFile, $prLog);
+if ($lockFile)
+{
+    if (-f $lockFile)
+    {
+	open(FILE, "< $lockFile") or
+	    $prLog->print('-kind' => 'E',
+			  '-str' => ["cannot read lock file <$lockFile>"],
+			  '-exit' => 1);
+	my $pid = <FILE>;
+	chop $pid;
+	close(FILE);
+	$prLog->print('-kind' => 'E',
+		      '-str' => ["strange format in lock file <$lockFile>, " .
+				 "line is <$pid>"],
+		      '-exit' => 1)
+	    unless ($pid =~ /\A\d+\Z/o);
+	if (kill(0, $pid) == 1)   # alte Instanz luft noch
+	{
+	    $prLog->print('-kind' => 'E',
+			  '-str' => ["cannot start, old instance with pid " .
+				     "<$pid> is allready running"],
+			  '-exit' => 1);
+	}
+	else
+	{
+	    $prLog->print('-kind' => 'I',
+			  '-str' => ["removing old lock file of process <$pid>"]
+			  );
+	}
+    }
+
+    open(FILE, "> $lockFile") or
+	$prLog->print('-kind' => 'E',
+		      '-str' => ["cannot create lock file <$lockFile>"],
+		      '-exit' => 1);
+    print FILE "$$\n";
+    close(FILE);
+}
 
 my $statDelOldBackupDirs =
     statisticDeleteOldBackupDirs->new('-prLog' => $prLog);
@@ -671,20 +677,4 @@ $prLog->print('-kind' => 'I',
 	      '-str' => ["removing lock file <$lockFile>"]);
 unlink $lockFile;
 
-$prLog->print('-kind' => 'Z',
-	      '-str' =>
-	      ["finished deletion in <$backupDir>, series <$series>"]);
-
-
 exit 0;
-
-
-##################################################
-# package printLogMultiple needs this function
-sub cleanup
-{
-    my $signame = shift;
-    my $exit = (shift() || 1);
-
-    exit $exit;
-}
